# Install

```bash
pip install githubdata
```

# Quick Start

```python
import githubdata as gd


github_url = 'https://github.com/imahdimir/d-TSETMC_ID-2-FirmTicker'
df = gd.get_data_from_github(github_url)
```

- That is easy as that!
